use serde::Deserialize;
use std::collections::BTreeMap;

#[derive(Deserialize)]
pub struct LicenseParagraph {
    pub license: String,
    #[serde(flatten)]
    pub other: BTreeMap<String, String>,
}

#[derive(Deserialize)]
pub struct FilesParagraph {
    #[serde(rename = "Files")]
    pub files: Vec<String>,
    #[serde(rename = "Copyright")]
    pub copyright: String,
    #[serde(rename = "License")]
    pub license: String,
    #[serde(rename = "Files-Excluded")]
    pub files_excluded: Vec<String>,
    #[serde(flatten)]
    pub other: BTreeMap<String, String>,
}

#[derive(Deserialize)]
pub enum Paragraph {
    #[serde(rename = "Files")]
    Files(FilesParagraph),
    #[serde(rename = "License")]
    License(LicenseParagraph),
}

#[derive(Deserialize)]
pub struct Header {
    #[serde(rename = "Format")]
    pub format: String,
    #[serde(rename = "Upstream-Name")]
    pub upstream_name: String,
    #[serde(rename = "Upstream-Contact")]
    pub upstream_contact: String,
    #[serde(rename = "Source")]
    pub source: String,

    #[serde(flatten)]
    pub other: BTreeMap<String, String>,
}

#[derive(Deserialize)]
pub struct CopyrightFile {
    pub header: Header,
    pub paragraphs: Vec<Paragraph>,
}
